@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -576,7 +576,9 @@ TEST_CASE("[Widget]")
         REQUIRE(parent->getWidgets().size() == 1);
         parent->loadWidgetsFromFile("WidgetFileClickableWidget1.txt");
         REQUIRE(parent->getWidgets().size() == 1);
+        std::streambuf *oldbuf = std::cerr.rdbuf(nullptr); // Ignore warning about duplicate name being used
         parent->loadWidgetsFromFile("WidgetFileClickableWidget1.txt", false);
+        std::cerr.rdbuf(oldbuf);
         REQUIRE(parent->getWidgets().size() == 2);
     }
 
@@ -637,6 +639,28 @@ TEST_CASE("[Widget]")
 
             TEST_DRAW("OriginScaleRotation.png")
         }
+
+        SECTION("Font scale")
+        {
+            auto button = tgui::Button::create();
+            button->setSize(150, 50);
+            button->setText("Scaling");
+            button->setTextSize(32);
+            button->setPosition(5, 10);
+
+            TEST_DRAW_INIT(400, 175, button)
+
+            auto oldView = gui.getView();
+            gui.setAbsoluteView({0, 0, 160, 70});
+
+            TEST_DRAW("FontScale_Unscaled.png")
+
+            tgui::getBackend()->setFontScale(2.5f);
+            TEST_DRAW("FontScale_Scaled.png")
+
+            tgui::getBackend()->setFontScale(1);
+            gui.setAbsoluteView(oldView.getRect());
+        }
     }
 
     SECTION("Bug Fixes")
