@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -133,6 +133,14 @@ TEST_CASE("[CanvasSFML]")
             REQUIRE(canvas->getViewport() == tgui::IntRect(20, 20, 100, 60));
         }
 
+        SECTION("Smooth")
+        {
+            canvas->setSmooth(true);
+            REQUIRE(canvas->isSmooth());
+            canvas->setSmooth(false);
+            REQUIRE(!canvas->isSmooth());
+        }
+
         SECTION("internal render texture")
         {
             canvas = tgui::CanvasSFML::create({50, 50});
